==> ejc-proequipmentcorp-impl-3.0.0-20221124.024157-181-sources.jar: com/ejianc/business/proequipmentcorpout/outrent/service/impl/OutRentSettlementBpmServiceImpl.java <==
package com.ejianc.business.proequipmentcorpout.outrent.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.order.api.IRentReceiptsApi;
import com.ejianc.business.order.enums.RentReceiptsEnum;
import com.ejianc.business.proequipmentcorpout.contract.bean.OutRentContractEntity;
import com.ejianc.business.proequipmentcorpout.contract.enums.PerformanceStatusEnum;
import com.ejianc.business.proequipmentcorpout.contract.enums.RentalSettlementStateEnum;
import com.ejianc.business.proequipmentcorpout.contract.service.IOutRentContractService;
import com.ejianc.business.proequipmentcorpout.rental.service.IOutRentRentalService;
import com.ejianc.business.proequipmentcorprent.ac.enums.BillPushStatusEnum;
import com.ejianc.business.procost.api.ICostDetailApi;
import com.ejianc.business.proequipmentcorpout.outrent.bean.OutRentSettlementEntity;
import com.ejianc.business.proequipmentcorpout.outrent.bean.OutRentSettlementRentalEntity;
import com.ejianc.business.proequipmentcorpout.outrent.service.IOutRentSettlementService;
import com.ejianc.business.proequipmentcorpout.outrent.vo.OutRentSettlementVO;
import com.ejianc.business.proequipmentcorprent.rent.service.IRentRentalService;
import com.ejianc.business.targetcost.api.IExecutionApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.BillStateEnum;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.stream.Collectors;

@Service("outRentSettlement")
public class OutRentSettlementBpmServiceImpl implements ICommonBusinessService {

    @Autowired
    private IBillTypeApi billTypeApi;
	@Autowired
	private IOutRentSettlementService service;
	@Autowired
	private IOutRentContractService contractService;//租赁合同
	private Logger logger = LoggerFactory.getLogger(this.getClass());
	@Autowired
	private IExecutionApi executionApi;
	@Autowired
	private IOutRentRentalService rentRentalService;
	@Autowired
	private ICostDetailApi costDetailApi;
	@Autowired
	private IRentReceiptsApi receiptsApi;

	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//结算单  根据 合同状态校验
		OutRentSettlementEntity entity = service.selectById(billId);
		if(entity.getContractId()!=null){
			OutRentContractEntity contractEntity = contractService.selectById(entity.getContractId());
			if(PerformanceStatusEnum.已冻结.getCode().equals(contractEntity.getContractPerformanceState()) || PerformanceStatusEnum.已作废.getCode().equals(contractEntity.getContractPerformanceState())){
				throw new BusinessException("合同{"+contractEntity.getContractName()+"},状态为："+ PerformanceStatusEnum.getEnumByCode(contractEntity.getContractPerformanceState()).getDescription()+"不可进行此操作！");
			}
		}
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		CommonResponse<String> res = billTypeApi.checkQuote(billTypeCode, billId);
		logger.info("平台返回查询被引用情况"+res.isSuccess()+"----"+res.getMsg());
		if(!res.isSuccess()) {
			return CommonResponse.error("当前单据已被下游业务引用，不能弃审！");
		}
		return CommonResponse.success();

	};

	/**
	 * 有审批流的撤回后回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		//结算单  根据 合同状态校验
		OutRentSettlementEntity entity = service.selectById(billId);
		if(entity.getContractId()!=null){
			OutRentContractEntity contractEntity = contractService.selectById(entity.getContractId());
			if(PerformanceStatusEnum.已冻结.getCode().equals(contractEntity.getContractPerformanceState()) || PerformanceStatusEnum.已作废.getCode().equals(contractEntity.getContractPerformanceState())){
				throw new BusinessException("合同{"+contractEntity.getContractName()+"},状态为："+ PerformanceStatusEnum.getEnumByCode(contractEntity.getContractPerformanceState()).getDescription()+"不可进行此操作！");
			}
		}
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//结算单  根据 合同状态校验
		OutRentSettlementEntity entity = service.selectById(billId);
		if(entity.getContractId()!=null){
			OutRentContractEntity contractEntity = contractService.selectById(entity.getContractId());
			if(PerformanceStatusEnum.已冻结.getCode().equals(contractEntity.getContractPerformanceState()) || PerformanceStatusEnum.已作废.getCode().equals(contractEntity.getContractPerformanceState())){
				throw new BusinessException("合同{"+contractEntity.getContractName()+"},状态为："+ PerformanceStatusEnum.getEnumByCode(contractEntity.getContractPerformanceState()).getDescription()+"不可进行此操作！");
			}
		}
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		if (BillStateEnum.COMMITED_STATE.getBillStateCode().equals(state) || BillStateEnum.PASSED_STATE
				.getBillStateCode().equals(state)) {
			logger.info("审批通过业务开始！");
			//结算单
			OutRentSettlementEntity entity = service.selectById(billId);
            //推送结算池所用vo
            OutRentSettlementVO settlementVO = BeanMapper.map(entity, OutRentSettlementVO.class);
			//修改合同状态  结算类型，0-过程,1-最终
			if (entity.getContractId() != null && entity.getSettlementType() == 1) {
				OutRentContractEntity rentContractEntity = contractService.selectById(entity.getContractId());
				rentContractEntity.setContractPerformanceState(PerformanceStatusEnum.已终止.getCode());
				contractService.saveOrUpdate(rentContractEntity);
				logger.info("修改合同状态！" + JSONObject.toJSONString(rentContractEntity));
			}
            //推送合同池
            service.updateContractPoolSettle(settlementVO,true);
			//租金占用
			if(CollectionUtils.isNotEmpty(entity.getRentSettlementRentalList())){
				List<OutRentSettlementRentalEntity> rentalList = entity.getRentSettlementRentalList();
				List<Long> ids = rentalList.stream().filter(t -> t.getSourceId() != null).map(OutRentSettlementRentalEntity::getSourceId).collect(Collectors.toList());
				rentRentalService.updateRentalSettlementState(ids, RentalSettlementStateEnum.已结算.getCode());
			}

//			logger.info("推送成本---");
//			service.costPush(entity);

//			//推送项目方
			logger.info("推送项目方数据entity：{}", JSONObject.toJSONString(entity));

			if(entity.getRentHarborType() == 1) { //内租 推项目验收
				//将租出单位信息赋值给组织
				entity.setOrgId(entity.getOutOrgId());
				entity.setOrgName(entity.getOutOrgName());
				entity.setOrgCode(entity.getOutOrgCode());
				CommonResponse<String> response = receiptsApi.receiptsSync((JSONObject) JSONObject.toJSON(entity), RentReceiptsEnum.租赁合同结算单.getName());
				if(!response.isSuccess()){
					throw new BusinessException(response.getMsg());
				}
			}
		}
		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		CommonResponse<String> res = billTypeApi.checkQuote(billTypeCode, billId);
		logger.info("平台返回查询被引用情况"+res.isSuccess()+"----"+res.getMsg());
		if(!res.isSuccess()) {
			return CommonResponse.error("当前单据已被下游业务引用，不能弃审！");
		}
		OutRentSettlementEntity entity = service.selectById(billId);
		if(entity.getSignStatus()==1){
			throw new BusinessException("已签字不能撤回！");
		}
		if(entity.getContractId()!=null){
			LambdaQueryWrapper<OutRentSettlementEntity> lambda = new LambdaQueryWrapper<>();
			lambda.eq(OutRentSettlementEntity::getContractId, entity.getContractId());
			lambda.orderByDesc(OutRentSettlementEntity::getCreateTime);
			List<OutRentSettlementEntity> list = service.list(lambda);
			OutRentSettlementEntity settlementEntity = list.get(0);
			if(!entity.getId().equals(settlementEntity.getId())){
				throw new BusinessException("只能撤回最新的结算单！");
			}
		}
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		OutRentSettlementEntity entity = service.selectById(billId);
		//修改合同状态  结算类型，0-过程,1-最终
		if(entity.getContractId()!=null && entity.getSettlementType()==1){
			OutRentContractEntity contractEntity = contractService.selectById(entity.getContractId());
			contractEntity.setContractPerformanceState(PerformanceStatusEnum.履约中.getCode());
			contractService.saveOrUpdate(contractEntity);
			logger.info("修改合同状态！" + JSONObject.toJSONString(contractEntity));
		}
		//租金占用
		if(CollectionUtils.isNotEmpty(entity.getRentSettlementRentalList())){
			List<OutRentSettlementRentalEntity> rentalList = entity.getRentSettlementRentalList();
			List<Long> ids = rentalList.stream().filter(t -> t.getSourceId() != null).map(OutRentSettlementRentalEntity::getSourceId).collect(Collectors.toList());
			rentRentalService.updateRentalSettlementState(ids, RentalSettlementStateEnum.未结算.getCode());
		}

//		logger.info("弃审推送成本---");
//		logger.info("删除成本中心之前的数据-Id---{}",entity.getId());
//		CommonResponse<String> stringCommonResponse = costDetailApi.deleteSubject(entity.getId());
//		logger.info("结果"+ JSONObject.toJSONString(stringCommonResponse));
//		if(!stringCommonResponse.isSuccess()){
//			throw new BusinessException(stringCommonResponse.getMsg());
//		}

		if(entity.getRentHarborType() == 1) { //内租 推项目验收
			CommonResponse<String> response = receiptsApi.delReceipts(entity.getId(), RentReceiptsEnum.租赁合同结算单.getName());
			if(!response.isSuccess()){
				throw new BusinessException(response.getMsg());
			}
		}
		//更新是否关联
//		LambdaUpdateWrapper<OutRentSettlementEntity> updateWrapper = new LambdaUpdateWrapper<>();
//		updateWrapper.in(OutRentSettlementEntity::getId, entity.getId());
//		updateWrapper.set(OutRentSettlementEntity::getRelationFlag, "0");//(1:是，0：否)
//		updateWrapper.set(OutRentSettlementEntity::getBillPushFlag, BillPushStatusEnum.未成功推送.getStatus());
//		service.update(updateWrapper);
		return CommonResponse.success();
	}

}

==> ejc-proequipmentcorp-impl-3.0.0-20221228.101101-280-sources.jar: com/ejianc/business/proequipmentcorpout/outrent/service/impl/OutRentSettlementBpmServiceImpl.java <==
package com.ejianc.business.proequipmentcorpout.outrent.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.order.api.IRentReceiptsApi;
import com.ejianc.business.order.enums.RentReceiptsEnum;
import com.ejianc.business.proequipmentcorpout.contract.bean.OutRentContractEntity;
import com.ejianc.business.proequipmentcorpout.contract.enums.PerformanceStatusEnum;
import com.ejianc.business.proequipmentcorpout.contract.enums.RentalSettlementStateEnum;
import com.ejianc.business.proequipmentcorpout.contract.service.IOutRentContractService;
import com.ejianc.business.proequipmentcorpout.rental.service.IOutRentRentalService;
import com.ejianc.business.proequipmentcorprent.ac.enums.BillPushStatusEnum;
import com.ejianc.business.procost.api.ICostDetailApi;
import com.ejianc.business.proequipmentcorpout.outrent.bean.OutRentSettlementEntity;
import com.ejianc.business.proequipmentcorpout.outrent.bean.OutRentSettlementRentalEntity;
import com.ejianc.business.proequipmentcorpout.outrent.service.IOutRentSettlementService;
import com.ejianc.business.proequipmentcorpout.outrent.vo.OutRentSettlementVO;
import com.ejianc.business.proequipmentcorprent.rent.service.IRentRentalService;
import com.ejianc.business.targetcost.api.IExecutionApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.BillStateEnum;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.stream.Collectors;

@Service("outRentSettlement")
public class OutRentSettlementBpmServiceImpl implements ICommonBusinessService {

    @Autowired
    private IBillTypeApi billTypeApi;
	@Autowired
	private IOutRentSettlementService service;
	@Autowired
	private IOutRentContractService contractService;//租赁合同
	private Logger logger = LoggerFactory.getLogger(this.getClass());
	@Autowired
	private IExecutionApi executionApi;
	@Autowired
	private IOutRentRentalService rentRentalService;
	@Autowired
	private ICostDetailApi costDetailApi;
	@Autowired
	private IRentReceiptsApi receiptsApi;

	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//结算单  根据 合同状态校验
		OutRentSettlementEntity entity = service.selectById(billId);
		if(entity.getContractId()!=null){
			OutRentContractEntity contractEntity = contractService.selectById(entity.getContractId());
			if(PerformanceStatusEnum.已冻结.getCode().equals(contractEntity.getContractPerformanceState()) || PerformanceStatusEnum.已作废.getCode().equals(contractEntity.getContractPerformanceState())){
				throw new BusinessException("合同{"+contractEntity.getContractName()+"},状态为："+ PerformanceStatusEnum.getEnumByCode(contractEntity.getContractPerformanceState()).getDescription()+"不可进行此操作！");
			}
		}
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		CommonResponse<String> res = billTypeApi.checkQuote(billTypeCode, billId);
		logger.info("平台返回查询被引用情况"+res.isSuccess()+"----"+res.getMsg());
		if(!res.isSuccess()) {
			return CommonResponse.error("当前单据已被下游业务引用，不能弃审！");
		}
		return CommonResponse.success();

	};

	/**
	 * 有审批流的撤回后回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		//结算单  根据 合同状态校验
		OutRentSettlementEntity entity = service.selectById(billId);
		if(entity.getContractId()!=null){
			OutRentContractEntity contractEntity = contractService.selectById(entity.getContractId());
			if(PerformanceStatusEnum.已冻结.getCode().equals(contractEntity.getContractPerformanceState()) || PerformanceStatusEnum.已作废.getCode().equals(contractEntity.getContractPerformanceState())){
				throw new BusinessException("合同{"+contractEntity.getContractName()+"},状态为："+ PerformanceStatusEnum.getEnumByCode(contractEntity.getContractPerformanceState()).getDescription()+"不可进行此操作！");
			}
		}
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//结算单  根据 合同状态校验
		OutRentSettlementEntity entity = service.selectById(billId);
		if(entity.getContractId()!=null){
			OutRentContractEntity contractEntity = contractService.selectById(entity.getContractId());
			if(PerformanceStatusEnum.已冻结.getCode().equals(contractEntity.getContractPerformanceState()) || PerformanceStatusEnum.已作废.getCode().equals(contractEntity.getContractPerformanceState())){
				throw new BusinessException("合同{"+contractEntity.getContractName()+"},状态为："+ PerformanceStatusEnum.getEnumByCode(contractEntity.getContractPerformanceState()).getDescription()+"不可进行此操作！");
			}
		}
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		if (BillStateEnum.COMMITED_STATE.getBillStateCode().equals(state) || BillStateEnum.PASSED_STATE
				.getBillStateCode().equals(state)) {
			logger.info("审批通过业务开始！");
			//结算单
			OutRentSettlementEntity entity = service.selectById(billId);
            //推送结算池所用vo
            OutRentSettlementVO settlementVO = BeanMapper.map(entity, OutRentSettlementVO.class);
			//修改合同状态  结算类型，0-过程,1-最终
			if (entity.getContractId() != null && entity.getSettlementType() == 1) {
				OutRentContractEntity rentContractEntity = contractService.selectById(entity.getContractId());
				rentContractEntity.setContractPerformanceState(PerformanceStatusEnum.已终止.getCode());
				contractService.saveOrUpdate(rentContractEntity);
				logger.info("修改合同状态！" + JSONObject.toJSONString(rentContractEntity));
			}
            //推送合同池
            service.updateContractPoolSettle(settlementVO,true);
			//租金占用
			if(CollectionUtils.isNotEmpty(entity.getRentSettlementRentalList())){
				List<OutRentSettlementRentalEntity> rentalList = entity.getRentSettlementRentalList();
				List<Long> ids = rentalList.stream().filter(t -> t.getSourceId() != null).map(OutRentSettlementRentalEntity::getSourceId).collect(Collectors.toList());
				rentRentalService.updateRentalSettlementState(ids, RentalSettlementStateEnum.已结算.getCode());
			}

//			logger.info("推送成本---");
//			service.costPush(entity);

//			//推送项目方
			OutRentSettlementVO outRentSettlementVO = BeanMapper.map(entity, OutRentSettlementVO.class);

			logger.info("推送项目方数据outRentSettlementVO：{}", JSONObject.toJSONString(outRentSettlementVO));

			if(outRentSettlementVO.getRentHarborType() == 1) { //内租 推项目验收
				//将租出单位信息赋值给组织
				outRentSettlementVO.setOrgId(outRentSettlementVO.getOutOrgId());
				outRentSettlementVO.setOrgName(outRentSettlementVO.getOutOrgName());
				outRentSettlementVO.setOrgCode(outRentSettlementVO.getOutOrgCode());

				outRentSettlementVO.setRentType(outRentSettlementVO.getRentHarborType());
				outRentSettlementVO.setRentTypeName(outRentSettlementVO.getRentHarborTypeName());
				CommonResponse<String> response = receiptsApi.receiptsSync((JSONObject) JSONObject.toJSON(outRentSettlementVO), RentReceiptsEnum.租赁合同结算单.getName());
				if(!response.isSuccess()){
					throw new BusinessException(response.getMsg());
				}
			}
		}
		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		CommonResponse<String> res = billTypeApi.checkQuote(billTypeCode, billId);
		logger.info("平台返回查询被引用情况"+res.isSuccess()+"----"+res.getMsg());
		if(!res.isSuccess()) {
			return CommonResponse.error("当前单据已被下游业务引用，不能弃审！");
		}
		OutRentSettlementEntity entity = service.selectById(billId);
		if(entity.getSignStatus()==1){
			throw new BusinessException("已签字不能撤回！");
		}
		if(entity.getContractId()!=null){
			LambdaQueryWrapper<OutRentSettlementEntity> lambda = new LambdaQueryWrapper<>();
			lambda.eq(OutRentSettlementEntity::getContractId, entity.getContractId());
			lambda.orderByDesc(OutRentSettlementEntity::getCreateTime);
			List<OutRentSettlementEntity> list = service.list(lambda);
			OutRentSettlementEntity settlementEntity = list.get(0);
			if(!entity.getId().equals(settlementEntity.getId())){
				throw new BusinessException("只能撤回最新的结算单！");
			}
		}
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		OutRentSettlementEntity entity = service.selectById(billId);
		//修改合同状态  结算类型，0-过程,1-最终
		if(entity.getContractId()!=null && entity.getSettlementType()==1){
			OutRentContractEntity contractEntity = contractService.selectById(entity.getContractId());
			contractEntity.setContractPerformanceState(PerformanceStatusEnum.履约中.getCode());
			contractService.saveOrUpdate(contractEntity);
			logger.info("修改合同状态！" + JSONObject.toJSONString(contractEntity));
		}
		//租金占用
		if(CollectionUtils.isNotEmpty(entity.getRentSettlementRentalList())){
			List<OutRentSettlementRentalEntity> rentalList = entity.getRentSettlementRentalList();
			List<Long> ids = rentalList.stream().filter(t -> t.getSourceId() != null).map(OutRentSettlementRentalEntity::getSourceId).collect(Collectors.toList());
			rentRentalService.updateRentalSettlementState(ids, RentalSettlementStateEnum.未结算.getCode());
		}

//		logger.info("弃审推送成本---");
//		logger.info("删除成本中心之前的数据-Id---{}",entity.getId());
//		CommonResponse<String> stringCommonResponse = costDetailApi.deleteSubject(entity.getId());
//		logger.info("结果"+ JSONObject.toJSONString(stringCommonResponse));
//		if(!stringCommonResponse.isSuccess()){
//			throw new BusinessException(stringCommonResponse.getMsg());
//		}

		if(entity.getRentHarborType() == 1) { //内租 推项目验收
			CommonResponse<String> response = receiptsApi.delReceipts(entity.getId(), RentReceiptsEnum.租赁合同结算单.getName());
			if(!response.isSuccess()){
				throw new BusinessException(response.getMsg());
			}
		}
		//更新是否关联
//		LambdaUpdateWrapper<OutRentSettlementEntity> updateWrapper = new LambdaUpdateWrapper<>();
//		updateWrapper.in(OutRentSettlementEntity::getId, entity.getId());
//		updateWrapper.set(OutRentSettlementEntity::getRelationFlag, "0");//(1:是，0：否)
//		updateWrapper.set(OutRentSettlementEntity::getBillPushFlag, BillPushStatusEnum.未成功推送.getStatus());
//		service.update(updateWrapper);
		return CommonResponse.success();
	}

}
